package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.DeviceGroupMapper;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.WebTempMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IDevice;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.scan.tasks.scheduler.PeriodTask;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.scan.tasks.scheduler.job.DevFindJob;
import com.datacloudsec.scan.tasks.scheduler.time.TimeIntervalHour;
import com.datacloudsec.scan.tasks.scheduler.time.TimeMonthly;
import com.datacloudsec.scan.tasks.scheduler.time.TimeMutilDay;
import com.datacloudsec.scan.tasks.scheduler.time.TimeWeek;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.ExcelUtil;
import com.datacloudsec.utils.FreemarkUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.PoiExcelUtils;
import com.datacloudsec.utils.ReflectUtils;
import com.datacloudsec.utils.SecretUtil;
import com.datacloudsec.utils.SystemUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.google.common.collect.Iterables;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.Set;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.FilenameUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.util.CellRangeAddress;
import sun.misc.BASE64Encoder;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/DeviceService.class */
public class DeviceService implements IDevice {
    private DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private DeviceGroupMapper deviceGroupMapper = (DeviceGroupMapper) InstanceUtil.newDaoInstance(DeviceGroupMapper.class);
    private WebTempMapper webTempMapper = (WebTempMapper) InstanceUtil.newDaoInstance(WebTempMapper.class);
    private IEngine engineService = (IEngine) InstanceUtil.newServiceInstance(EngineService.class);
    private Logger LOG = Logger.getLogger(DeviceService.class);

    public int searchCount(HttpSession session, String ip, String name, Integer type, Integer regionSid, Integer regionCid, String[] dgid) throws Exception {
        return this.deviceMapper.searchCount(ip, name, type, regionSid, regionCid, dgid, DataRule.getRuleWhere(session, "t_device"));
    }

    public List<Map<String, Object>> search(HttpSession session, String ip, String name, Integer type, Integer regionSid, Integer regionCid, String[] dgid, Integer offset, Integer limit) throws Exception {
        return this.deviceMapper.search(ip, name, type, regionSid, regionCid, dgid, offset, limit, DataRule.getRuleWhere(session, "t_device"));
    }

    public int searchTaskDevCount(HttpSession session, String ip, String name, Integer type, Integer regionSid, Integer regionCid) throws Exception {
        return this.deviceMapper.searchTaskDevCount(ip, name, type, regionSid, regionCid, DataRule.getRuleWhere(session, "t_task"));
    }

    public List<Map<String, Object>> searchTaskDev(HttpSession session, String ip, String name, Integer type, Integer regionSid, Integer regionCid, Integer offset, Integer limit) throws Exception {
        return this.deviceMapper.searchTaskDev(ip, name, type, regionSid, regionCid, offset, limit, DataRule.getRuleWhere(session, "t_task"));
    }

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        Integer vcount = Integer.valueOf(this.deviceMapper.delete(id, version, DataRule.getRuleWhere(session, "t_device")));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    @Transactional
    public Integer insert(HttpSession session, String name, String ip, String desct, Integer regionSid, Integer regionCid, String authContent, String confContent, Integer dgid, String val1, String val2) throws Exception {
        User user = (User) session.getAttribute("userInfo");
        Integer count = this.deviceMapper.getDevCountByName(name, user != null ? user.getId() : null, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("资产名称已存在【" + name + "】！");
        }
        Map<String, Object> confMap = (Map) JsonUtil.MAPPER_ESCAPE_HTML.readValue(confContent, new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.DeviceService.1
        });
        Map<String, Object> device = new HashMap<>();
        device.put("name", name);
        device.put("ip", ip);
        device.put("type", StringUtils.join(confMap.keySet(), ","));
        device.put("desct", desct);
        device.put("regionSid", regionSid);
        device.put("regionCid", regionCid);
        device.put("confContent", confContent);
        device.put("authContent", authContent);
        if (user != null) {
            device.put("uid", user.getId());
        }
        device.put("dgid", dgid);
        device.put("val1", val1);
        device.put("val2", val2);
        this.deviceMapper.insert(device);
        return ObjectUtil.getInt(device.get("id"));
    }

    public void update(HttpSession session, Integer id, String name, String ip, String desct, Integer regionSid, Integer regionCid, Integer version, String authContent, String confContent, Integer dgid, String val1, String val2) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.deviceMapper.getDevCountByName(name, uid, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("资产名称已存在！");
        }
        Object rule = DataRule.getRuleWhere(session, "t_device");
        Map<String, Object> confMap = (Map) JsonUtil.MAPPER.readValue(confContent, new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.DeviceService.2
        });
        Map<String, Object> device = new HashMap<>();
        device.put("id", id);
        device.put("name", name);
        device.put("ip", ip);
        device.put("type", StringUtils.join(confMap.keySet(), ","));
        device.put("desct", desct);
        device.put("regionSid", regionSid);
        device.put("regionCid", regionCid);
        device.put("confContent", confContent);
        device.put("authContent", authContent);
        device.put("version", version);
        device.put("rule", rule);
        device.put("uid", uid);
        device.put("dgid", dgid);
        device.put("val1", val1);
        device.put("val2", val2);
        Integer vcount = Integer.valueOf(this.deviceMapper.update(device));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public List<Map<String, Object>> getRegionByName(String name) throws Exception {
        return this.deviceMapper.getRegionByName(name);
    }

    public Map<String, Object> getRegionById(Integer id) throws Exception {
        return this.deviceMapper.getRegionById(id);
    }

    public List<Map<String, Object>> getRegionByPid(Integer parentId) throws Exception {
        return this.deviceMapper.getRegionByPid(parentId);
    }

    public Map<String, Object> getDevById(Integer id) throws Exception {
        return this.deviceMapper.getDevById(id);
    }

    public Map<String, Object> getDevDetailById(Integer id) throws Exception {
        return this.deviceMapper.getDevDetailById(id);
    }

    public int insertDevFindParams(String ip, String port, Integer uid, String pingonly, String servciescan, Integer type, String periodTime, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String portType, String portscan, String hostIp, String zombiehost, String zombieHosts) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("devfind")) {
            throw new UEException("资产探测未授权");
        }
        Integer taskid = add(null, ip, port, uid, pingonly, servciescan, type, periodTime, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, portType, portscan, hostIp, zombiehost, zombieHosts);
        if (type.intValue() == 1) {
            try {
                start(taskid);
            } catch (Exception e) {
                this.LOG.error("立即扫描异常", e);
            }
        }
        startTimer(taskid, type, periodTime, alarmType, alarmMethod, alarmTime);
        return taskid.intValue();
    }

    public void updDevFindParams(Integer id, String ip, String port, Integer uid, String pingonly, String servciescan, Integer type, String periodTime, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String portType, String portscan, String hostIp, String zombiehost, String zombieHosts) throws Exception {
        add(id, ip, port, uid, pingonly, servciescan, type, periodTime, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, portType, portscan, hostIp, zombiehost, zombieHosts);
        stopTimer(id);
        startTimer(id, type, periodTime, alarmType, alarmMethod, alarmTime);
    }

    private void stopTimer(Integer taskid) throws Exception {
        if (taskid == null) {
            return;
        }
        PeriodTask.getInstance().removeJob("devfind_alerm_" + taskid);
        PeriodTask.getInstance().removeJob("devfind_scan_" + taskid);
    }

    public void startTimer(Integer taskid, Integer type, String periodTime, Integer alarmType, String alarmMethod, String alarmTime) throws Exception {
        if (type.intValue() == 2) {
            String[] entryPeriod = periodTime.split(":");
            String periodId = "devfind_scan_" + taskid;
            if (periodTime.charAt(0) == '0') {
                Map<String, Object> map = new HashMap<>();
                map.put("taskid", taskid);
                PeriodTask.getInstance().addJob(DevFindJob.class, new TimeMonthly(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), ObjectUtil.getInt(entryPeriod[3]).intValue()), periodId, map);
            } else if (periodTime.charAt(0) == '1') {
                Map<String, Object> map2 = new HashMap<>();
                map2.put("taskid", taskid);
                PeriodTask.getInstance().addJob(DevFindJob.class, new TimeWeek(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), ObjectUtil.getInt(entryPeriod[3]).intValue()), periodId, map2);
            } else if (periodTime.charAt(0) == '2') {
                Map<String, Object> map3 = new HashMap<>();
                map3.put("taskid", taskid);
                PeriodTask.getInstance().addJob(DevFindJob.class, new TimeMutilDay(0, ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue()), periodId, map3);
            } else if (periodTime.charAt(0) == '3') {
                Map<String, Object> map4 = new HashMap<>();
                map4.put("taskid", taskid);
                PeriodTask.getInstance().addJob(DevFindJob.class, new TimeMutilDay(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), ObjectUtil.getInt(entryPeriod[3]).intValue()), periodId, map4);
            } else if (periodTime.charAt(0) == '4') {
                Map<String, Object> map5 = new HashMap<>();
                map5.put("taskid", taskid);
                PeriodTask.getInstance().addJob(DevFindJob.class, new TimeIntervalHour(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), 0), periodId, map5);
            }
        }
        if (alarmType.intValue() == 2) {
            if (alarmMethod.contains("mail") || alarmMethod.contains("sms")) {
                String[] at = alarmTime.split(":");
                Map<String, Object> map6 = new HashMap<>();
                map6.put("taskid", taskid);
                PeriodTask.getInstance().addJob(AlermJob.class, new TimeMutilDay(0, ObjectUtil.getInt(at[0]).intValue(), ObjectUtil.getInt(at[1]).intValue()), "devfind_alerm_" + taskid, map6);
            }
        }
    }

    private Integer add(Integer id, String ip, String port, Integer uid, String pingonly, String servciescan, Integer type, String periodTime, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String portType, String portscan, String hostIp, String zombiehost, String zombieHosts) throws Exception {
        Map<String, Object> params = new HashMap<>();
        params.put("ip", ip);
        params.put("port", port);
        params.put("uid", uid);
        params.put("pingonly", pingonly);
        params.put("servciescan", servciescan);
        params.put("type", type);
        params.put("periodTime", periodTime);
        params.put("alarmMethod", alarmMethod);
        params.put("alarmType", alarmType);
        params.put("alarmTime", alarmTime);
        params.put("mailAddr", mailAddr);
        params.put("smsAddr", smsAddr);
        params.put("val1", portType);
        params.put("val2", portscan);
        params.put("val3", hostIp);
        params.put("zombiehost", zombiehost);
        params.put("zombieHosts", zombieHosts);
        if (id != null) {
            params.put("id", id);
        }
        if (id == null) {
            this.deviceMapper.insertDevFindParams(params);
        } else {
            this.deviceMapper.updDevFindParams(params);
        }
        return ObjectUtil.getInt(params.get("id"));
    }

    @Transactional
    public void delDevFindParam(Integer id) throws Exception {
        Map<String, Object> devFind = this.deviceMapper.getDevfindParamById(id);
        int status = ObjectUtil.getInt(devFind.get("status"), 0);
        if (status == 1) {
            throw new UEException("当前资产正在扫描中...");
        }
        this.deviceMapper.delDevfindResByFid(id);
        this.deviceMapper.delDevFindParam(id);
        stopTimer(id);
    }

    public Map<String, Object> getDevfindParamById(Integer id) throws Exception {
        return this.deviceMapper.getDevfindParamById(id);
    }

    public List<Map<String, Object>> getDevByIp(HttpSession session, String ip, Integer taskType, Integer type) throws Exception {
        return this.deviceMapper.getDevByIp(ip, taskType, type, DataRule.getRuleWhere(session, "t_task"));
    }

    public List<Map<String, Object>> getDevByIp(Integer uid, String ip, Integer taskType, Integer type) throws Exception {
        return this.deviceMapper.getDevByIpAndUid(uid, ip, taskType, type);
    }

    /* JADX WARN: Removed duplicated region for block: B:55:0x02b4  */
    /* JADX WARN: Removed duplicated region for block: B:58:0x02e6  */
    /* JADX WARN: Removed duplicated region for block: B:61:0x0395  */
    /* JADX WARN: Removed duplicated region for block: B:64:0x03cd  */
    /* JADX WARN: Removed duplicated region for block: B:67:0x0422  */
    /* JADX WARN: Removed duplicated region for block: B:70:0x042a  */
    /* JADX WARN: Removed duplicated region for block: B:71:0x03d3  */
    /* JADX WARN: Removed duplicated region for block: B:72:0x039b  */
    /* JADX WARN: Removed duplicated region for block: B:73:0x02ea  */
    /* JADX WARN: Removed duplicated region for block: B:74:0x02b8  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public java.util.Map<java.lang.String, java.lang.Object> webImp(java.io.File r6, java.lang.Integer r7, javax.servlet.http.HttpSession r8) throws java.lang.Exception {
        /*
            Method dump skipped, instructions count: 1134
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.datacloudsec.scan.service.impl.DeviceService.webImp(java.io.File, java.lang.Integer, javax.servlet.http.HttpSession):java.util.Map");
    }

    public File webExp(String name, HttpSession session) throws Exception {
        String[] headers = {"网站名称@name@8000", "网站地址@url@8000", "REFERER@referer@4000", "方法@method@4000", "POST数据@postBody@4000", "网站类型@webType@5000", "所属省份/直辖市@region@6000", "所属城市@city@4000", "描述@desct@8000"};
        PoiExcelUtils poiExcelUtil = new PoiExcelUtils();
        HSSFWorkbook hssfWorkbook = poiExcelUtil.getHSSFWorkbook();
        HSSFSheet hssfSheet = poiExcelUtil.getHSSFSheet(hssfWorkbook, "网站信息列表");
        poiExcelUtil.writeHeader(hssfWorkbook, hssfSheet, headers, "网站信息列表");
        writeContentCustom(poiExcelUtil, hssfWorkbook, hssfSheet, headers, this.deviceMapper.search((String) null, name, 1, (Integer) null, (Integer) null, (String[]) null, (Integer) null, (Integer) null, DataRule.getRuleWhere(session, "t_device")), 2);
        File f = new File(Constant.WORK_DIR, ObjectUtil.getString(String.valueOf(System.currentTimeMillis()) + ".xls", ""));
        FileOutputStream out = null;
        try {
            try {
                out = FileUtils.openOutputStream(f);
                hssfWorkbook.write(out);
                IOUtils.closeQuietly(out);
                return f;
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(out);
            throw th;
        }
    }

    private void writeContentCustom(PoiExcelUtils poiExcelUtils, HSSFWorkbook hssfWorkbook, HSSFSheet hssfSheet, String[] headers, List<?> dataList, int startIndex) throws Exception {
        Object cellValue;
        int rownum = startIndex;
        HSSFCellStyle cellStyle = poiExcelUtils.createContentCellStyle(hssfWorkbook);
        if (!CollectionUtils.isEmpty(dataList)) {
            int size = dataList.size();
            for (int j = 0; j < size; j++) {
                HSSFRow row = hssfSheet.createRow(rownum);
                Map<String, Object> map = (Map) dataList.get(j);
                int len = headers.length;
                for (int i = 0; i < len; i++) {
                    HSSFCell cell = row.createCell(i);
                    String key = ObjectUtil.getString(headers[i].split("@")[1].trim(), "");
                    if (map != null) {
                        cellValue = map.get(key);
                    } else {
                        cellValue = ReflectUtils.getValueOfGetIncludeObjectFeild(dataList.get(j), key);
                    }
                    Map<String, Object> conf = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map.get("confContent"), ""), HashMap.class);
                    Map<String, Object> webConf = (Map) conf.get(ReportService.REPORT_STATE_SUCCESS);
                    if (key.equals("url")) {
                        cellValue = ObjectUtil.getString(webConf.get("url"), "");
                    } else if (key.equals("referer")) {
                        cellValue = ObjectUtil.getString(webConf.get("referer"), "");
                    } else if (key.equals("method")) {
                        cellValue = ObjectUtil.getString(webConf.get("method"), "");
                    } else if (key.equals("postBody")) {
                        cellValue = ObjectUtil.getString(webConf.get("postBody"), "");
                    } else if (key.equals("webType")) {
                        cellValue = ObjectUtil.getString(webConf.get("webType"), "");
                    }
                    poiExcelUtils.cellValueHandler(cell, cellValue);
                    cell.setCellStyle(cellStyle);
                }
                rownum++;
            }
        }
    }

    public List<Map<String, Object>> getProvinceByName(String name) throws Exception {
        return this.deviceMapper.getProvinceByName(name);
    }

    public File devFindExp(HttpSession session, String taskid) throws Exception {
        HSSFWorkbook hssfWorkbook = writeContentDevFind(session, taskid);
        File f = new File(Constant.WORK_DIR, ObjectUtil.getString(String.valueOf(System.currentTimeMillis()) + ".xls", ""));
        FileOutputStream out = null;
        try {
            try {
                out = FileUtils.openOutputStream(f);
                hssfWorkbook.write(out);
                IOUtils.closeQuietly(out);
                return f;
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(out);
            throw th;
        }
    }

    private void parsePort(List<Map<String, Object>> list, Map<String, List<String>> currPort, Map<String, List<String>> nextPort) throws Exception {
        List<String> nextPList;
        for (Map<String, Object> row : list) {
            String host = ObjectUtil.getString(row.get("host"), "");
            List<String> pList = null;
            if (currPort != null) {
                pList = currPort.get(host);
            }
            if (pList == null) {
                pList = new ArrayList();
            }
            row.put("currPort", StringUtils.join(pList, ","));
            if (nextPort != null && (nextPList = nextPort.get(host)) != null) {
                List<String> newP = new ArrayList<>();
                for (String p : pList) {
                    if (!nextPList.contains(p)) {
                        newP.add(p);
                    }
                }
                row.put("newPort", StringUtils.join(newP, ","));
                List<String> closeP = new ArrayList<>();
                for (String p2 : nextPList) {
                    if (!pList.contains(p2)) {
                        closeP.add(p2);
                    }
                }
                row.put("closePort", StringUtils.join(closeP, ","));
            }
        }
    }

    public File devFindExp2(HttpSession session, Integer id) throws Exception {
        byte[] result;
        Map<String, Object> r = new HashMap<>();
        File logo = new File(Constant.WORK_DIR, "resource/doc-logo.png");
        byte[] content = FileUtils.readFileToByteArray(logo);
        try {
            result = SecretUtil.decryptEncrypt("aes", content, "anshuyun123SEF@#".getBytes());
        } catch (Exception e) {
            result = content;
        }
        String logoBase64 = new BASE64Encoder().encode(result);
        Properties oem = (Properties) InitSystemTask.servletContext.getAttribute("oem");
        r.put("headerLogo", logoBase64);
        r.put("headerText", oem.getProperty("copyright"));
        r.put("footerUrl", oem.getProperty("copyright-url"));
        Map<String, String> portEntry = new HashMap<>();
        portEntry.put("synscan", "TCP SYN");
        portEntry.put("ackscan", "TCP ACK");
        portEntry.put("connect", "TCP Connect");
        portEntry.put("tcpfin", "TCP FIN");
        portEntry.put("tcpnull", "TCP NULL");
        portEntry.put("xmas", "Xmas scan");
        portEntry.put("udpscan", "UDP");
        portEntry.put("idlescan", "idle扫描");
        r.put("portEntry", portEntry);
        r.put("currdate", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        List<Map<String, Object>> findRecord = this.deviceMapper.findRecord(id);
        r.put("findRecord", findRecord);
        r.put("task", this.deviceMapper.getDevfindParamById(id));
        List<Map<String, Object>> results = this.deviceMapper.getDevfindResByFid(id);
        Map<String, List<Map<String, Object>>> scanResult = new HashMap<>();
        Map<String, List<String>> scanHost = new HashMap<>();
        Map<String, Map<String, List<String>>> scanPort = new HashMap<>();
        if (results != null && results.size() > 0) {
            for (Map<String, Object> map : results) {
                String taskid = ObjectUtil.getString(map.get("taskid"), "");
                String host = ObjectUtil.getString(map.get("host"), "");
                List<Map<String, Object>> list = scanResult.get(taskid);
                if (list == null) {
                    list = new ArrayList<>();
                    scanResult.put(taskid, list);
                }
                list.add(map);
                List<String> hosts = scanHost.get(taskid);
                if (hosts == null) {
                    hosts = new ArrayList<>();
                    scanHost.put(taskid, hosts);
                }
                hosts.add(host);
                Map<String, List<String>> portMap = scanPort.get(taskid);
                if (portMap == null) {
                    portMap = new HashMap<>();
                    scanPort.put(taskid, portMap);
                }
                List<String> port = portMap.get(host);
                if (port == null) {
                    port = new ArrayList<>();
                    portMap.put(host, port);
                }
                List<?> portList = (List) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map.get("ports"), "[]"), List.class);
                for (Object row2 : portList) {
                    Map<?, ?> p = (Map) row2;
                    port.add(ObjectUtil.getString(p.get("port"), ""));
                }
            }
        }
        for (int i = 0; i < findRecord.size(); i++) {
            Map<String, Object> row = findRecord.get(i);
            String taskid2 = row.get("taskid").toString();
            List<Map<String, Object>> list2 = scanResult.get(taskid2);
            if (list2 == null) {
                list2 = new ArrayList();
            }
            row.put("list", list2);
            Map<String, List<String>> nextPorts = null;
            if (i < findRecord.size() - 1) {
                Map<String, Object> map2 = findRecord.get(i + 1);
                nextPorts = scanPort.get(map2.get("taskid").toString());
            }
            parsePort(list2, scanPort.get(taskid2), nextPorts);
            List<Map<String, Object>> newList = new ArrayList<>();
            if (i < findRecord.size() - 1) {
                Map<String, Object> map3 = findRecord.get(i + 1);
                List<String> nextHost = scanHost.get(map3.get("taskid").toString());
                for (Map<String, Object> row1 : list2) {
                    if (!nextHost.contains(ObjectUtil.getString(row1.get("host"), ""))) {
                        newList.add(row1);
                    }
                }
            }
            row.put("newList", newList);
            parsePort(newList, scanPort.get(taskid2), null);
            List<Map<String, Object>> closeList = new ArrayList<>();
            if (i < findRecord.size() - 1) {
                Map<String, Object> map4 = findRecord.get(i + 1);
                List<String> currHost = scanHost.get(taskid2);
                List<Map<String, Object>> nextList = scanResult.get(map4.get("taskid").toString());
                if (nextList != null) {
                    for (Map<String, Object> row12 : nextList) {
                        if (!currHost.contains(ObjectUtil.getString(row12.get("host"), ""))) {
                            closeList.add(row12);
                        }
                    }
                }
            }
            row.put("closeList", closeList);
            parsePort(closeList, nextPorts, null);
        }
        File f = new File(Constant.TEMP_DIR, ObjectUtil.getString(String.valueOf(System.nanoTime()) + ".doc", ""));
        f.createNewFile();
        OutputStream os = null;
        try {
            os = new FileOutputStream(f);
            FreemarkUtil.out(r, os, "/report/devfind/find.xml", InitSystemTask.servletContext);
            IOUtils.closeQuietly(os);
            return f;
        } catch (Throwable th) {
            IOUtils.closeQuietly(os);
            throw th;
        }
    }

    private HSSFWorkbook writeContentDevFind(HttpSession session, String taskid) throws Exception {
        Object valueOfGetIncludeObjectFeild;
        String[] headers = {"IP地址@host@8000", "MAC地址@mac@8000", "所属区域@area@4000", "操作系统@system@8000", "主机名称@hostname@4000", "标签@val3@4000", "备注信息@val2@4000", "端口变化情况@portChange@8000"};
        String[] headersPort = {"端口号@port", "@x", "协议类型@protocol", "@x", "服务@service", "@x", "版本@version", "@x"};
        PoiExcelUtils poiExcelUtil = new PoiExcelUtils();
        HSSFWorkbook hssfWorkbook = poiExcelUtil.getHSSFWorkbook();
        List<Map<String, Object>> devData = this.deviceMapper.getDevfindByTaskid(taskid, (Integer) null, (Integer) null);
        Iterable<List<Map<String, Object>>> data = Iterables.partition(devData, 50);
        int num = 1;
        for (List<Map<String, Object>> dataList : data) {
            HSSFSheet hssfSheet = poiExcelUtil.getHSSFSheet(hssfWorkbook, "资产探测结果" + num);
            poiExcelUtil.writeHeader(hssfWorkbook, hssfSheet, headers, "资产探测结果" + num);
            Object cellValue = null;
            int rownum = 2;
            HSSFCellStyle cellStyle = poiExcelUtil.createContentCellStyle(hssfWorkbook);
            HSSFCellStyle boldCell = poiExcelUtil.createBoldCellStyle(hssfWorkbook);
            if (!CollectionUtils.isEmpty(dataList)) {
                int size = dataList.size();
                for (int j = 0; j < size; j++) {
                    HSSFRow row = hssfSheet.createRow(rownum);
                    Map<String, Object> map = dataList.get(j);
                    int len = headers.length;
                    for (int i = 0; i < len; i++) {
                        HSSFCell cell = row.createCell(i);
                        String key = ObjectUtil.getString(headers[i].split("@")[1].trim(), "");
                        if (map != null) {
                            if ("val3".equalsIgnoreCase(key)) {
                                cellValue = ObjectUtil.getString(map.get(key), "").replace("\n", ",");
                            } else if ("portChange".equalsIgnoreCase(key)) {
                                List<Map<String, Object>> devs = this.deviceMapper.getDevfindByFidAndIp(ObjectUtil.getInt(map.get("fid")), ObjectUtil.getString(map.get("host"), ""));
                                if (devs != null && devs.size() >= 2) {
                                    Set<Integer> ports1 = new HashSet<>();
                                    String portsStr = ObjectUtil.getString(devs.get(devs.size() - 2).get("ports"), "");
                                    if (StringUtils.isNotBlank(portsStr)) {
                                        List<Map<String, Object>> portList = (List) JsonUtil.MAPPER.readValue(portsStr, List.class);
                                        for (Map<String, Object> p : portList) {
                                            ports1.add(ObjectUtil.getInt(p.get("port")));
                                        }
                                    }
                                    Set<Integer> ports2 = new HashSet<>();
                                    String portsStr2 = ObjectUtil.getString(devs.get(devs.size() - 1).get("ports"), "");
                                    if (StringUtils.isNotBlank(portsStr2)) {
                                        List<Map<String, Object>> portList2 = (List) JsonUtil.MAPPER.readValue(portsStr2, List.class);
                                        for (Map<String, Object> p2 : portList2) {
                                            ports2.add(ObjectUtil.getInt(p2.get("port")));
                                        }
                                    }
                                    List<Integer> already = new ArrayList<>();
                                    List<Integer> add = new ArrayList<>();
                                    List<Integer> del = new ArrayList<>();
                                    for (Integer p1 : ports1) {
                                        boolean delBl = true;
                                        Iterator<Integer> it = ports2.iterator();
                                        while (true) {
                                            if (!it.hasNext()) {
                                                break;
                                            }
                                            if (p1.intValue() == it.next().intValue()) {
                                                delBl = false;
                                                break;
                                            }
                                        }
                                        if (delBl) {
                                            del.add(p1);
                                        }
                                    }
                                    for (Integer p22 : ports2) {
                                        boolean addBl = true;
                                        Iterator<Integer> it2 = ports1.iterator();
                                        while (true) {
                                            if (!it2.hasNext()) {
                                                break;
                                            }
                                            Integer p12 = it2.next();
                                            if (p12.intValue() == p22.intValue()) {
                                                already.add(p12);
                                                addBl = false;
                                                break;
                                            }
                                        }
                                        if (addBl) {
                                            add.add(p22);
                                        }
                                    }
                                    cellValue = new HSSFRichTextString("未变化：" + StringUtils.join(already, ",") + "\r\n新增端口：" + StringUtils.join(add, ",") + "\r\n减少端口：" + StringUtils.join(del, ","));
                                }
                            } else {
                                cellValue = map.get(key);
                            }
                        } else {
                            cellValue = ReflectUtils.getValueOfGetIncludeObjectFeild(dataList.get(j), key);
                        }
                        poiExcelUtil.cellValueHandler(cell, cellValue);
                        cell.setCellStyle(cellStyle);
                    }
                    rownum++;
                    String portsStr3 = ObjectUtil.getString(map.get("ports"), "");
                    if (StringUtils.isNotBlank(portsStr3)) {
                        HSSFRow row2 = hssfSheet.createRow(rownum);
                        List<Integer> cols = new ArrayList<>();
                        for (int i2 = 0; i2 < headersPort.length; i2++) {
                            HSSFCell cell2 = row2.createCell(i2);
                            poiExcelUtil.cellValueHandler(cell2, headersPort[i2].split("@")[0]);
                            cell2.setCellStyle(boldCell);
                            cols.add(Integer.valueOf(i2));
                        }
                        Iterable<List<Integer>> colList = Iterables.partition(cols, 2);
                        for (List<Integer> col : colList) {
                            hssfSheet.addMergedRegion(new CellRangeAddress(rownum, rownum, col.get(0).intValue(), col.get(1).intValue()));
                        }
                        rownum++;
                        List<Map<String, Object>> ports = (List) JsonUtil.MAPPER.readValue(portsStr3, ArrayList.class);
                        for (Map<String, Object> port : ports) {
                            HSSFRow row3 = hssfSheet.createRow(rownum);
                            int len2 = headersPort.length;
                            for (int i3 = 0; i3 < len2; i3++) {
                                HSSFCell cell3 = row3.createCell(i3);
                                String key2 = ObjectUtil.getString(headersPort[i3].split("@")[1].trim(), "");
                                if (port != null) {
                                    valueOfGetIncludeObjectFeild = port.get(key2);
                                } else {
                                    valueOfGetIncludeObjectFeild = ReflectUtils.getValueOfGetIncludeObjectFeild(dataList.get(j), key2);
                                }
                                cellValue = valueOfGetIncludeObjectFeild;
                                poiExcelUtil.cellValueHandler(cell3, cellValue);
                                cell3.setCellStyle(cellStyle);
                            }
                            for (List<Integer> col2 : colList) {
                                hssfSheet.addMergedRegion(new CellRangeAddress(rownum, rownum, col2.get(0).intValue(), col2.get(1).intValue()));
                            }
                            rownum++;
                        }
                    }
                }
            }
            num++;
        }
        return hssfWorkbook;
    }

    public File devBackup(HttpSession session) throws Exception {
        File f = new File(Constant.WORK_DIR, String.valueOf(System.nanoTime()) + ".backup");
        FileOutputStream fos = null;
        ObjectOutputStream oos = null;
        try {
            try {
                List<Map<String, Object>> device = this.deviceMapper.getDevInfo(DataRule.getRuleWhere(session, "t_device"));
                List<Map<String, Object>> devGroup = this.deviceGroupMapper.search((String) null, (String) null, (String) null, (Integer) null, (Integer) null, DataRule.getRuleWhere(session, "t_device_group"));
                Map<String, List<Map<String, Object>>> result = new HashMap<>();
                result.put("device", device);
                result.put("devGroup", devGroup);
                fos = new FileOutputStream(f);
                oos = new ObjectOutputStream(fos);
                oos.writeObject(result);
                IOUtils.closeQuietly(oos);
                IOUtils.closeQuietly(fos);
                return f;
            } catch (Exception e) {
                if (f != null && f.exists()) {
                    f.delete();
                }
                throw e;
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(oos);
            IOUtils.closeQuietly(fos);
            throw th;
        }
    }

    @Transactional
    public Map<String, Object> devRestore(HttpSession session, File f) throws Exception {
        FileInputStream fis = null;
        ObjectInputStream ois = null;
        int success = 0;
        int fail = 0;
        try {
            try {
                fis = new FileInputStream(f);
                ois = new ObjectInputStream(fis);
                Map<String, Object> result = (Map) ois.readObject();
                User u = (User) session.getAttribute("userInfo");
                List<Map<String, Object>> devGroup = (List) result.get("devGroup");
                if (CollectionUtils.isEmpty(devGroup)) {
                    throw new UEException("无资产组");
                }
                List<String> devGroupNames = this.deviceGroupMapper.getDevGroupName(DataRule.getRuleWhere(session, "t_device_group"));
                Iterator<Map<String, Object>> iterDevGroup = devGroup.iterator();
                while (iterDevGroup.hasNext()) {
                    Map<String, Object> map = iterDevGroup.next();
                    if (devGroupNames.contains(ObjectUtil.getString(map.get("name"), ""))) {
                        iterDevGroup.remove();
                        fail++;
                    } else {
                        map.put("uid", u.getId());
                        success++;
                    }
                }
                if (CollectionUtils.isNotEmpty(devGroup)) {
                    this.deviceGroupMapper.impDeviceGroup(devGroup);
                }
                List<Map<String, Object>> device = (List) result.get("device");
                List<String> devNames = this.deviceMapper.getDevName(DataRule.getRuleWhere(session, "t_device"));
                Iterator<Map<String, Object>> iter = device.iterator();
                while (iter.hasNext()) {
                    Map<String, Object> map2 = iter.next();
                    if (devNames.contains(ObjectUtil.getString(map2.get("name"), ""))) {
                        iter.remove();
                        fail++;
                    } else {
                        map2.put("uid", u.getId());
                        success++;
                    }
                }
                if (CollectionUtils.isNotEmpty(device)) {
                    this.deviceMapper.impDevice(device);
                }
                Map<String, Object> res = new HashMap<>();
                res.put("successCount", Integer.valueOf(success));
                res.put("failCount", Integer.valueOf(fail));
                return res;
            } catch (Exception e) {
                if (f != null && f.exists()) {
                    f.delete();
                }
                throw new UEException("恢复失败0条", e);
            }
        } finally {
            IOUtils.closeQuietly(ois);
            IOUtils.closeQuietly(fis);
            if (f != null && f.exists()) {
                f.delete();
            }
        }
    }

    public List<Map<String, Object>> getDevFindList(HttpSession session, String ip, String port, Integer status, String startTime, String endTime, Integer offset, Integer limit) throws Exception {
        return this.deviceMapper.getDevFindList(ip, port, status, startTime, endTime, offset, limit, DataRule.getRuleWhere(session, "t_devfind_params"));
    }

    public Integer getDevFindCount(HttpSession session, String ip, String port, Integer status, String startTime, String endTime, Integer offset, Integer limit) throws Exception {
        return this.deviceMapper.getDevFindCount(ip, port, status, startTime, endTime, offset, limit, DataRule.getRuleWhere(session, "t_devfind_params"));
    }

    @Transactional
    public void start(Integer id) throws Exception {
        if (id == null) {
            return;
        }
        Map<String, Object> devParam = this.deviceMapper.getDevfindParamById(id);
        if (ObjectUtil.getInt(devParam.get("status")).intValue() != 1) {
            int resCount = this.deviceMapper.getDevParamTidCount(id);
            if (resCount >= 5) {
                this.deviceMapper.delDevParamMinTaskid(id);
            }
            String pingonly = ObjectUtil.getString(devParam.get("pingonly"), "no");
            String servciescan = ObjectUtil.getString(devParam.get("servciescan"), "no");
            String portscan = ObjectUtil.getString(devParam.get("val2"), "");
            String zombiehost = ObjectUtil.getString(devParam.get("zombiehost"), "");
            Map<String, Object> params = new HashMap<>();
            params.put("id", id);
            params.put("offset", 0);
            params.put("progress", 0);
            IEngine.EngineResult engineResult = this.engineService.sniffingStart(ObjectUtil.getString(devParam.get("ip"), ""), ObjectUtil.getString(devParam.get("port"), ""), pingonly, servciescan, portscan, zombiehost);
            if (engineResult != null) {
                params.put("status", 1);
                params.put("scanCount", Integer.valueOf(ObjectUtil.getInt(devParam.get("scanCount"), 0) + 1));
                params.put("taskid", engineResult.getEngineId());
                params.put("localeid", Integer.valueOf(engineResult.getLocalId()));
                params.put("startTime", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
                params.put("endTime", null);
            } else {
                params.put("status", 4);
            }
            this.deviceMapper.scanUpdDevFind(params);
        }
    }

    public void stop(Integer id) throws Exception {
        Map<String, Object> devParam = this.deviceMapper.getDevfindParamById(id);
        if (ObjectUtil.getInt(devParam.get("status")).intValue() != 1) {
            throw new UEException("此任务未进行扫描");
        }
        this.engineService.sniffingStop(ObjectUtil.getString(devParam.get("taskid"), ""), ObjectUtil.getInt(devParam.get("localeid")).intValue());
        Map<String, Object> params = new HashMap<>();
        params.put("id", id);
        params.put("status", 2);
        params.put("endTime", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        this.deviceMapper.syncDevFind(params);
    }

    public List<Map<String, Object>> getDevfindByTaskid(String taskid, Integer offset, Integer limit) throws Exception {
        return this.deviceMapper.getDevfindByTaskid(taskid, offset, limit);
    }

    public List<Map<String, Object>> getDevfindByFidAndIp(Integer fid, String ip) throws Exception {
        return this.deviceMapper.getDevfindByFidAndIp(fid, ip);
    }

    public int addDesct(Integer id, String desct) throws Exception {
        return this.deviceMapper.addDesct(id, desct);
    }

    public int addFlag(Integer id, String flag) throws Exception {
        return this.deviceMapper.addFlag(id, flag);
    }

    public List<Map<String, Object>> getRegions(Integer id, Integer parentId, String name) throws Exception {
        return this.deviceMapper.getRegions(id, parentId, name);
    }

    public int insertCookie(Integer deviceid, List<Map<String, Object>> list) throws Exception {
        return this.deviceMapper.insertCookie(deviceid, list);
    }

    public int updStatus(Integer id, Integer status, Integer port, Integer proid) throws Exception {
        return this.deviceMapper.updStatus(id, status, port, proid);
    }

    public List<Map<String, Object>> getCookiesByDeviceid(Integer id, Integer offset, Integer limit) throws Exception {
        return this.deviceMapper.getCookiesByDeviceid(id, offset, limit);
    }

    public int delCookiesByDeviceid(Integer id) throws Exception {
        return this.deviceMapper.delCookiesByDeviceid(id);
    }

    public int delCookieById(Integer id) throws Exception {
        return this.deviceMapper.delCookieById(id);
    }

    public int getCookiesCountByDeviceid(Integer id) throws Exception {
        return this.deviceMapper.getCookiesCountByDeviceid(id);
    }

    public List<Map<String, Object>> getDeviceByIds(Integer[] ids) throws Exception {
        return this.deviceMapper.getDeviceByIds(ids);
    }

    public List<Integer> impDevice(HttpSession session, FileItem file, Integer dgid) throws Exception {
        File f = SystemUtil.uploadFile(file, Constant.TEMP_DIR, String.valueOf(System.nanoTime()) + "." + FilenameUtils.getExtension(file.getName()));
        ExcelUtil excelUtil = new ExcelUtil();
        Workbook workbook = excelUtil.getWorkbook(f);
        User user = (User) session.getAttribute("userInfo");
        List<Integer> ids = new ArrayList<>();
        handSys(excelUtil.readXlsx(workbook.getSheetAt(0), 2, 19, (Integer) null, new int[]{0, 1, 2, 3, 14, 15}), Integer.valueOf(user == null ? 1 : user.getId().intValue()), dgid, ids);
        handDb(excelUtil.readXlsx(workbook.getSheetAt(1), 2, 15, (Integer) null, new int[]{0, 1, 2, 3, 7, 8}), Integer.valueOf(user == null ? 1 : user.getId().intValue()), dgid, ids);
        handMid(excelUtil.readXlsx(workbook.getSheetAt(2), 2, 19, (Integer) null, new int[]{0, 1, 2, 3, 14, 15}), Integer.valueOf(user == null ? 1 : user.getId().intValue()), dgid, ids);
        handSec(excelUtil.readXlsx(workbook.getSheetAt(3), 2, 17, (Integer) null, new int[]{0, 1, 2, 3, 14, 15}), Integer.valueOf(user == null ? 1 : user.getId().intValue()), dgid, ids);
        handNetsec(excelUtil.readXlsx(workbook.getSheetAt(4), 2, 17, (Integer) null, new int[]{0, 1, 2, 3, 14, 15}), Integer.valueOf(user == null ? 1 : user.getId().intValue()), dgid, ids);
        handWmware(excelUtil.readXlsx(workbook.getSheetAt(5), 2, 16, (Integer) null, new int[]{0, 1, 2, 3, 14}), Integer.valueOf(user == null ? 1 : user.getId().intValue()), dgid, ids);
        handWlan(excelUtil.readXlsx(workbook.getSheetAt(6), 2, 15, (Integer) null, new int[]{0, 1, 2, 3, 14}), Integer.valueOf(user == null ? 1 : user.getId().intValue()), dgid, ids);
        return ids;
    }

    private Map<String, Object> authsData(String[] data) throws Exception {
        Map<String, Object> protocolMap = new HashMap<>();
        protocolMap.put("SSH(22)", "ssh");
        protocolMap.put("TELNET(23)", "telnet");
        protocolMap.put("SMB(445)", "smb");
        protocolMap.put("WinRM(5986)", "winrm");
        Map<String, Object> portMap = new HashMap<>();
        portMap.put("SSH(22)", "22");
        portMap.put("TELNET(23)", "23");
        portMap.put("SMB(445)", "445");
        portMap.put("WinRM(5986)", "5986");
        String protocol = ObjectUtil.getString(data[7], "");
        String port = ObjectUtil.getString(data[11], "");
        Map<String, Object> authsMap = new HashMap<>();
        authsMap.put("protocol", protocolMap.get(protocol));
        authsMap.put("uname", ObjectUtil.getString(data[8], ""));
        authsMap.put("password", ObjectUtil.getString(data[9], ""));
        authsMap.put("superPwd", ObjectUtil.getString(data[10], ""));
        authsMap.put("port", StringUtils.isBlank(port) ? portMap.get(protocol) : port);
        authsMap.put("share", ObjectUtil.getString(data[12], ""));
        authsMap.put("domain", ObjectUtil.getString(data[13], ""));
        return authsMap;
    }

    private Map<String, Object> deviceData(String[] data, Integer uid, Integer dgid) throws Exception {
        String name = ObjectUtil.getString(data[0], "");
        Integer count = this.deviceMapper.getDevCountByName(name, (Integer) null, (Integer) null);
        if (count != null && count.intValue() > 0) {
            return null;
        }
        Map<String, Object> device = new HashMap<>();
        device.put("name", name);
        device.put("ip", ObjectUtil.getString(data[1], ""));
        device.put("regionSid", ObjectUtil.getInt(((Map) this.deviceMapper.getRegionByName(data[2]).get(0)).get("id")));
        device.put("regionCid", ObjectUtil.getInt(((Map) this.deviceMapper.getRegionByName(data[3]).get(0)).get("id")));
        device.put("val1", ObjectUtil.getString(data[4], ""));
        device.put("val2", ObjectUtil.getString(data[5], ""));
        device.put("desct", ObjectUtil.getString(data[6], ""));
        device.put("uid", uid);
        device.put("dgid", dgid);
        return device;
    }

    private void handWlan(List<String[]> datas, Integer uid, Integer dgid, List<Integer> ids) throws Exception {
        for (String[] data : datas) {
            try {
                Map<String, Object> device = deviceData(data, uid, dgid);
                if (!MapUtils.isEmpty(device)) {
                    device.put("type", "11");
                    device.put("authContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(authsData(data)));
                    HashMap hashMap = new HashMap();
                    hashMap.put("linuxV", ObjectUtil.getString(data[14], ""));
                    Map<String, Object> conf = new HashMap<>();
                    conf.put("11", hashMap);
                    device.put("confContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(conf));
                    this.deviceMapper.insert(device);
                    ids.add(ObjectUtil.getInt(device.get("id")));
                }
            } catch (Exception e) {
                this.LOG.error("", e);
            }
        }
    }

    private void handWmware(List<String[]> datas, Integer uid, Integer dgid, List<Integer> ids) throws Exception {
        for (String[] data : datas) {
            try {
                Map<String, Object> device = deviceData(data, uid, dgid);
                if (!MapUtils.isEmpty(device)) {
                    device.put("type", "5");
                    device.put("authContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(authsData(data)));
                    HashMap hashMap = new HashMap();
                    hashMap.put("linuxV", ObjectUtil.getString(data[14], ""));
                    hashMap.put("offPwdFile", ObjectUtil.getString(data[15], ""));
                    hashMap.put("assetType", "hypervisor");
                    Map<String, Object> conf = new HashMap<>();
                    conf.put("5", hashMap);
                    device.put("confContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(conf));
                    this.deviceMapper.insert(device);
                    ids.add(ObjectUtil.getInt(device.get("id")));
                }
            } catch (Exception e) {
                this.LOG.error("", e);
            }
        }
    }

    private void handNetsec(List<String[]> datas, Integer uid, Integer dgid, List<Integer> ids) throws Exception {
        Map<String, Object> netType = new HashMap<>();
        netType.put("思科路由器/交换机", "cisco_switch");
        netType.put("华三路由器/交换机", "h3c_switch");
        netType.put("华为路由器/交换机", "huawei_switch");
        netType.put("锐捷交换机", "ruijie_switch");
        netType.put("中兴交换机", "zte_switch");
        netType.put("力腾交换机", "ftos_switch");
        netType.put("JUNIPER路由器", "juniper_route");
        for (String[] data : datas) {
            try {
                Map<String, Object> device = deviceData(data, uid, dgid);
                if (!MapUtils.isEmpty(device)) {
                    device.put("type", "4");
                    device.put("authContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(authsData(data)));
                    HashMap hashMap = new HashMap();
                    hashMap.put("checkWay", "remote");
                    hashMap.put("linuxV", netType.get(ObjectUtil.getString(data[15], "")));
                    hashMap.put("offPwdFile", ObjectUtil.getString(data[16], ""));
                    hashMap.put("assetType", "netsec");
                    Map<String, Object> conf = new HashMap<>();
                    conf.put("4", hashMap);
                    device.put("confContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(conf));
                    this.deviceMapper.insert(device);
                    ids.add(ObjectUtil.getInt(device.get("id")));
                }
            } catch (Exception e) {
                this.LOG.error("", e);
            }
        }
    }

    private void handSec(List<String[]> datas, Integer uid, Integer dgid, List<Integer> ids) throws Exception {
        Map<String, Object> secType = new HashMap<>();
        secType.put("思科防火墙", "cisco_firewall");
        secType.put("山石网科防火墙", "hillstone_firewall");
        secType.put("JUNIPER防火墙", "juniper_firewall");
        secType.put("NetScreen防火墙", "netscreen_firewall");
        secType.put("网神防火墙", "legendsec_firewall");
        secType.put("天融信防火墙", "topsec_firewall");
        secType.put("启明防火墙", "venus_firewall");
        secType.put("网御星云防火墙", "leadsec_firewall");
        secType.put("风云防火墙", "fengyun_firewall");
        secType.put("深信服防火墙", "sxf_firewall");
        secType.put("安数云网络入侵防御系统", "asy_ips");
        secType.put("华三防火墙", "h3c_firewall");
        secType.put("华为防火墙 ", "huawei_firewall");
        secType.put("飞塔防火墙", "fortinet_firewall");
        for (String[] data : datas) {
            try {
                Map<String, Object> device = deviceData(data, uid, dgid);
                if (!MapUtils.isEmpty(device)) {
                    device.put("type", "6");
                    device.put("authContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(authsData(data)));
                    HashMap hashMap = new HashMap();
                    hashMap.put("checkWay", "remote");
                    hashMap.put("linuxV", secType.get(ObjectUtil.getString(data[15], "")));
                    hashMap.put("offPwdFile", ObjectUtil.getString(data[16], ""));
                    hashMap.put("assetType", "netsec");
                    Map<String, Object> conf = new HashMap<>();
                    conf.put("6", hashMap);
                    device.put("confContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(conf));
                    this.deviceMapper.insert(device);
                    ids.add(ObjectUtil.getInt(device.get("id")));
                }
            } catch (Exception e) {
                this.LOG.error("", e);
            }
        }
    }

    private void handMid(List<String[]> datas, Integer uid, Integer dgid, List<Integer> ids) throws Exception {
        Map<String, Object> midType = new HashMap<>();
        midType.put("Apache(linux)", "apache_linux");
        midType.put("Apache(Windows)", "apache_windows");
        midType.put("Bind(Windows)", "bind_windows");
        midType.put("Domino(Linux)", "domino_linux");
        midType.put("IIS6(Windows)", "iis6_windows");
        midType.put("IIS7(Windows)", "iis7_windows");
        midType.put("JBoss4(linux)", "jboss4_linux");
        midType.put("Jboss4(Windows)", "jboss4_windows");
        midType.put("JBoss5(linux)", "jboss5_linux");
        midType.put("Jboss5(Windows)", "jboss5_windows");
        midType.put("JBoss6(linux)", "jboss6_linux");
        midType.put("Jboss6(Windows)", "jboss6_windows");
        midType.put("Ngnix(linux)", "nginx_linux");
        midType.put("Nginx(Windows)", "nginx_windows");
        midType.put("Resin(linux)", "resin_linux");
        midType.put("Resin(Windows)", "resin_windows");
        midType.put("Tomcat(linux)", "tomcat_linux");
        midType.put("Tomcat(Windows)", "tomcat_windows");
        midType.put("Tongweb4.6(Linux)", "tongweb46_linux");
        midType.put("Tongweb5.0(Linux)", "tongweb50_linux");
        midType.put("Tongweb5.0(Windows)", "tongweb50_windows");
        midType.put("Weblogic(linux)", "weblogic_linux");
        midType.put("Weblogic(Windows)", "weblogic_windows");
        midType.put("WebSphere(linux)", "websphere_linux");
        midType.put("Websphere(Windows)", "websphere_windows");
        for (String[] data : datas) {
            try {
                Map<String, Object> device = deviceData(data, uid, dgid);
                if (!MapUtils.isEmpty(device)) {
                    device.put("type", "3");
                    device.put("authContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(authsData(data)));
                    HashMap hashMap = new HashMap();
                    hashMap.put("linuxV", midType.get(ObjectUtil.getString(data[14], "")));
                    hashMap.put("path", ObjectUtil.getString(data[15], ""));
                    hashMap.put("offPwdFile", ObjectUtil.getString(data[16], ""));
                    hashMap.put("serverType", ObjectUtil.getString(data[17], ""));
                    hashMap.put("cellName", ObjectUtil.getString(data[18], ""));
                    hashMap.put("assetType", "middleware");
                    ArrayList arrayList = new ArrayList();
                    arrayList.add(hashMap);
                    Map<String, Object> conf = new HashMap<>();
                    conf.put("3", arrayList);
                    device.put("confContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(conf));
                    this.deviceMapper.insert(device);
                    ids.add(ObjectUtil.getInt(device.get("id")));
                }
            } catch (Exception e) {
                this.LOG.error("", e);
            }
        }
    }

    private void handDb(List<String[]> datas, Integer uid, Integer dgid, List<Integer> ids) throws Exception {
        Map<String, Object> dbType = new HashMap<>();
        dbType.put("Oracle（1521）", "001");
        dbType.put("MySql（3306）", "002");
        dbType.put("SqlServer（1433）", "003");
        dbType.put("PostgreSql（5432）", "004");
        dbType.put("DB2（50000）", "005");
        dbType.put("Sybase（5000）", "006");
        dbType.put("Informix（11300）", "007");
        dbType.put("达梦（5236）", "008");
        dbType.put("Kingbase（54321）", "009");
        dbType.put("南大通用（5258）", "010");
        dbType.put("MongoDb（27017）", "101");
        dbType.put("CouchDb（5984）", "102");
        dbType.put("Redis（6379）", "103");
        dbType.put("Memcache（11211）", "104");
        for (String[] data : datas) {
            try {
                Map<String, Object> device = deviceData(data, uid, dgid);
                if (!MapUtils.isEmpty(device)) {
                    device.put("type", ReportService.REPORT_STATE_FAILED);
                    HashMap hashMap = new HashMap();
                    hashMap.put("checkauth", "关系型数据库".equals(data[7]) ? "relat" : "nosql");
                    hashMap.put("db", dbType.get(data[8]));
                    hashMap.put("port", data[9]);
                    hashMap.put("username", data[10]);
                    hashMap.put("password", data[11]);
                    hashMap.put("dbname", data[12]);
                    hashMap.put("connect_type", "服务名".equals(data[13]) ? ReportService.REPORT_STATE_SUCCESS : ReportService.REPORT_STATE_FAILED);
                    hashMap.put("offPwdFile", data[14]);
                    ArrayList arrayList = new ArrayList();
                    arrayList.add(hashMap);
                    Map<String, Object> conf = new HashMap<>();
                    conf.put(ReportService.REPORT_STATE_FAILED, arrayList);
                    device.put("confContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(conf));
                    this.deviceMapper.insert(device);
                    ids.add(ObjectUtil.getInt(device.get("id")));
                }
            } catch (Exception e) {
                this.LOG.error("", e);
            }
        }
    }

    private void handSys(List<String[]> syss, Integer uid, Integer dgid, List<Integer> ids) throws Exception {
        Map<String, Object> linuxV = new HashMap<>();
        linuxV.put("手机、IPAD等", "other");
        linuxV.put("Centos(红帽移植版本)", "centos");
        linuxV.put("Debian", "debian");
        linuxV.put("Fedora(红帽开源版本)", "fedora");
        linuxV.put("OpenSuSE(SuSE开源版本)", "opensuse");
        linuxV.put("Redhat(红帽)", "redhat");
        linuxV.put("Suse(变色龙)", "suse");
        linuxV.put("Ubuntu(乌班图)", "ubuntu");
        linuxV.put("其它", "centos");
        linuxV.put("NeoKylin(中标麒麟)", "neokylin");
        linuxV.put("RedFlag(红旗)", "redflag");
        linuxV.put("Deepin(深度)", "deepin");
        linuxV.put("Solaris(Oracle甲骨文)", "solaris");
        linuxV.put("Aix(IBM)", "aix");
        linuxV.put("HP-UX(惠普)", "hpux");
        linuxV.put("Windows系列", "windows");
        Map<String, Object> assetType = new HashMap<>();
        assetType.put("手机、IPAD等", "other");
        assetType.put("Centos(红帽移植版本)", "linux");
        assetType.put("Debian", "linux");
        assetType.put("Fedora(红帽开源版本)", "linux");
        assetType.put("OpenSuSE(SuSE开源版本)", "linux");
        assetType.put("Redhat(红帽)", "linux");
        assetType.put("Suse(变色龙)", "linux");
        assetType.put("Ubuntu(乌班图)", "linux");
        assetType.put("其它", "linux");
        assetType.put("NeoKylin(中标麒麟)", "cos");
        assetType.put("RedFlag(红旗)", "cos");
        assetType.put("Deepin(深度)", "cos");
        assetType.put("Solaris(Oracle甲骨文)", "unix");
        assetType.put("Aix(IBM)", "unix");
        assetType.put("HP-UX(惠普)", "unix");
        assetType.put("Windows系列", "windows");
        for (String[] data : syss) {
            try {
                Map<String, Object> device = deviceData(data, uid, dgid);
                if (!MapUtils.isEmpty(device)) {
                    device.put("type", ReportService.REPORT_STATE_READY);
                    device.put("authContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(authsData(data)));
                    HashMap hashMap = new HashMap();
                    hashMap.put("linuxV", linuxV.get(ObjectUtil.getString(data[14], "")));
                    hashMap.put("assetType", assetType.get(ObjectUtil.getString(data[14], "")));
                    hashMap.put("checkmed", "在线检测".equals(ObjectUtil.getString(data[15], "")) ? "online" : "agent");
                    hashMap.put("offPwdFile", ObjectUtil.getString(data[16], ""));
                    hashMap.put("netbiosName", ObjectUtil.getString(data[17], ""));
                    hashMap.put("netbiosContent", ObjectUtil.getString(data[18], ""));
                    Map<String, Object> conf = new HashMap<>();
                    conf.put(ReportService.REPORT_STATE_READY, hashMap);
                    device.put("confContent", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(conf));
                    this.deviceMapper.insert(device);
                    ids.add(ObjectUtil.getInt(device.get("id")));
                }
            } catch (Exception e) {
                this.LOG.error("", e);
            }
        }
    }

    public void deleteForName(String name) {
        this.deviceMapper.deleteForName(name);
    }

    public Integer getDevRecordsCount(String cmp, String ip) throws Exception {
        return this.deviceMapper.getDevRecordsCount(cmp, ip);
    }

    public List<Map<String, Object>> getDevRecords(String cmp, String ip, Integer offset, Integer limit) throws Exception {
        return this.deviceMapper.getDevRecords(cmp, ip, offset, limit);
    }

    public Map<String, Object> getDevfindByTaskidAndIp(String taskid, String ip) throws Exception {
        return this.deviceMapper.getDevfindByTaskidAndIp(taskid, ip);
    }

    public int updTopologyJson(String taskid, String topologyJson) {
        return this.deviceMapper.updTopologyJson(taskid, topologyJson);
    }

    public Map<String, Object> getDevfindParamByTaskid(String taskid) throws Exception {
        return this.deviceMapper.getDevfindParamByTaskid(taskid);
    }

    public Integer getCountByTaskidAndIp(String taskid, String host) throws Exception {
        return this.deviceMapper.getCountByTaskidAndIp(taskid, host);
    }

    public Integer updDevfind(String taskid, String host, String hostHide, String mac, String system, String hostname) throws Exception {
        return this.deviceMapper.updDevfind(taskid, host, hostHide, mac, system, hostname);
    }

    public Integer getFindCountByTaskid(String taskid) throws Exception {
        return this.deviceMapper.getFindCountByTaskid(taskid);
    }

    public void batchUpdOwnDevgroup(Integer dgid, String[] id) throws Exception {
        this.deviceMapper.batchUpdOwnDevgroup(dgid, id);
    }

    public void batchInsert(List<Map<String, Object>> list) {
        this.deviceMapper.batchInsert(list);
    }
}
